Schema diff algorithm for generating migrations
Compares two schema states and generates the operations needed to transform one into the other.
Structs
- Column
Changes - Changes to apply to a column
Enums
- Schema
Operation - Operations that can be performed on a database schema
Functions
- generate_
diff - Generate diff between two schema states
- resolve_
delta - Resolve a delta migration by merging with base schema