pub fn generate_diff(
current: &[TableSchema],
target: &[TableSchema],
) -> Vec<SchemaOperation>Expand description
Generate diff between two schema states
Returns a list of operations to transform current into target.
pub fn generate_diff(
current: &[TableSchema],
target: &[TableSchema],
) -> Vec<SchemaOperation>Generate diff between two schema states
Returns a list of operations to transform current into target.